@@ -4,16 +4,14 @@ Main interface for rds-data service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_rds_data import (
         Client,
         RDSDataServiceClient,
     )
 
-    session = boto3.Session()
-
-    client: RDSDataServiceClient = boto3.client("rds-data")
-    session_client: RDSDataServiceClient = session.client("rds-data")
+    session = Session()
+    client: RDSDataServiceClient = session.client("rds-data")
     ```
 """
 from .client import RDSDataServiceClient
