@@ -1,15 +1,16 @@
 """
 Type annotations for rds-data service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/)
 
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_rds_data import RDSDataServiceClient
+    from boto3.session import Session
+    from mypy_boto3_rds_data.client import RDSDataServiceClient
 
-    client: RDSDataServiceClient = boto3.client("rds-data")
+    session = Session()
+    client: RDSDataServiceClient = session.client("rds-data")
     ```
 """
 from typing import Any, Dict, Mapping, Sequence, Type
@@ -50,8 +51,8 @@ class Exceptions:
 
 class RDSDataServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/rds-data.html#RDSDataService.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/)
     """
 
     meta: ClientMeta
@@ -60,6 +61,9 @@ class RDSDataServiceClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         RDSDataServiceClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#exceptions)
         """
 
     def batch_execute_statement(
@@ -76,8 +80,8 @@ class RDSDataServiceClient(BaseClient):
         """
         Runs a batch SQL statement over an array of data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#batch_execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#batch_execute_statement)
         """
 
     def begin_transaction(
@@ -86,16 +90,16 @@ class RDSDataServiceClient(BaseClient):
         """
         Starts a SQL transaction.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#begin_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#begin_transaction)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#can_paginate)
         """
 
     def commit_transaction(
@@ -105,8 +109,8 @@ class RDSDataServiceClient(BaseClient):
         Ends a SQL transaction started with the `BeginTransaction` operation and commits
         the changes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#commit_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#commit_transaction)
         """
 
     def execute_sql(
@@ -121,8 +125,8 @@ class RDSDataServiceClient(BaseClient):
         """
         Runs one or more SQL statements.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute_sql)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#execute_sql)
         """
 
     def execute_statement(
@@ -142,8 +146,8 @@ class RDSDataServiceClient(BaseClient):
         """
         Runs a SQL statement against a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#execute_statement)
         """
 
     def generate_presigned_url(
@@ -156,8 +160,8 @@ class RDSDataServiceClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#generate_presigned_url)
         """
 
     def rollback_transaction(
@@ -166,6 +170,6 @@ class RDSDataServiceClient(BaseClient):
         """
         Performs a rollback of a transaction.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client.html#rollback_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#rollback_transaction)
         """
