@@ -1,7 +1,7 @@
 """
 Type annotations for rds-data service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_rds_data/type_defs/)
 
 Usage::
 
@@ -15,6 +15,7 @@ import sys
 from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import DecimalReturnTypeType, TypeHintType
 
@@ -55,41 +56,26 @@ __all__ = (
 ArrayValueTypeDef = TypedDict(
     "ArrayValueTypeDef",
     {
-        "arrayValues": Sequence[Dict[str, Any]],
-        "booleanValues": Sequence[bool],
-        "doubleValues": Sequence[float],
-        "longValues": Sequence[int],
-        "stringValues": Sequence[str],
+        "arrayValues": NotRequired[Sequence[Dict[str, Any]]],
+        "booleanValues": NotRequired[Sequence[bool]],
+        "doubleValues": NotRequired[Sequence[float]],
+        "longValues": NotRequired[Sequence[int]],
+        "stringValues": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
-_RequiredBatchExecuteStatementRequestRequestTypeDef = TypedDict(
-    "_RequiredBatchExecuteStatementRequestRequestTypeDef",
+BatchExecuteStatementRequestRequestTypeDef = TypedDict(
+    "BatchExecuteStatementRequestRequestTypeDef",
     {
         "resourceArn": str,
         "secretArn": str,
         "sql": str,
+        "database": NotRequired[str],
+        "parameterSets": NotRequired[Sequence[Sequence["SqlParameterTypeDef"]]],
+        "schema": NotRequired[str],
+        "transactionId": NotRequired[str],
     },
 )
-_OptionalBatchExecuteStatementRequestRequestTypeDef = TypedDict(
-    "_OptionalBatchExecuteStatementRequestRequestTypeDef",
-    {
-        "database": str,
-        "parameterSets": Sequence[Sequence["SqlParameterTypeDef"]],
-        "schema": str,
-        "transactionId": str,
-    },
-    total=False,
-)
-
-
-class BatchExecuteStatementRequestRequestTypeDef(
-    _RequiredBatchExecuteStatementRequestRequestTypeDef,
-    _OptionalBatchExecuteStatementRequestRequestTypeDef,
-):
-    pass
-
 
 BatchExecuteStatementResponseTypeDef = TypedDict(
     "BatchExecuteStatementResponseTypeDef",
@@ -99,28 +85,15 @@ BatchExecuteStatementResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredBeginTransactionRequestRequestTypeDef = TypedDict(
-    "_RequiredBeginTransactionRequestRequestTypeDef",
+BeginTransactionRequestRequestTypeDef = TypedDict(
+    "BeginTransactionRequestRequestTypeDef",
     {
         "resourceArn": str,
         "secretArn": str,
+        "database": NotRequired[str],
+        "schema": NotRequired[str],
     },
 )
-_OptionalBeginTransactionRequestRequestTypeDef = TypedDict(
-    "_OptionalBeginTransactionRequestRequestTypeDef",
-    {
-        "database": str,
-        "schema": str,
-    },
-    total=False,
-)
-
-
-class BeginTransactionRequestRequestTypeDef(
-    _RequiredBeginTransactionRequestRequestTypeDef, _OptionalBeginTransactionRequestRequestTypeDef
-):
-    pass
-
 
 BeginTransactionResponseTypeDef = TypedDict(
     "BeginTransactionResponseTypeDef",
@@ -133,22 +106,21 @@ BeginTransactionResponseTypeDef = TypedDict(
 ColumnMetadataTypeDef = TypedDict(
     "ColumnMetadataTypeDef",
     {
-        "arrayBaseColumnType": int,
-        "isAutoIncrement": bool,
-        "isCaseSensitive": bool,
-        "isCurrency": bool,
-        "isSigned": bool,
-        "label": str,
-        "name": str,
-        "nullable": int,
-        "precision": int,
-        "scale": int,
-        "schemaName": str,
-        "tableName": str,
-        "type": int,
-        "typeName": str,
+        "arrayBaseColumnType": NotRequired[int],
+        "isAutoIncrement": NotRequired[bool],
+        "isCaseSensitive": NotRequired[bool],
+        "isCurrency": NotRequired[bool],
+        "isSigned": NotRequired[bool],
+        "label": NotRequired[str],
+        "name": NotRequired[str],
+        "nullable": NotRequired[int],
+        "precision": NotRequired[int],
+        "scale": NotRequired[int],
+        "schemaName": NotRequired[str],
+        "tableName": NotRequired[str],
+        "type": NotRequired[int],
+        "typeName": NotRequired[str],
     },
-    total=False,
 )
 
 CommitTransactionRequestRequestTypeDef = TypedDict(
@@ -168,29 +140,16 @@ CommitTransactionResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredExecuteSqlRequestRequestTypeDef = TypedDict(
-    "_RequiredExecuteSqlRequestRequestTypeDef",
+ExecuteSqlRequestRequestTypeDef = TypedDict(
+    "ExecuteSqlRequestRequestTypeDef",
     {
         "awsSecretStoreArn": str,
         "dbClusterOrInstanceArn": str,
         "sqlStatements": str,
+        "database": NotRequired[str],
+        "schema": NotRequired[str],
     },
 )
-_OptionalExecuteSqlRequestRequestTypeDef = TypedDict(
-    "_OptionalExecuteSqlRequestRequestTypeDef",
-    {
-        "database": str,
-        "schema": str,
-    },
-    total=False,
-)
-
-
-class ExecuteSqlRequestRequestTypeDef(
-    _RequiredExecuteSqlRequestRequestTypeDef, _OptionalExecuteSqlRequestRequestTypeDef
-):
-    pass
-
 
 ExecuteSqlResponseTypeDef = TypedDict(
     "ExecuteSqlResponseTypeDef",
@@ -200,34 +159,21 @@ ExecuteSqlResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredExecuteStatementRequestRequestTypeDef = TypedDict(
-    "_RequiredExecuteStatementRequestRequestTypeDef",
+ExecuteStatementRequestRequestTypeDef = TypedDict(
+    "ExecuteStatementRequestRequestTypeDef",
     {
         "resourceArn": str,
         "secretArn": str,
         "sql": str,
+        "continueAfterTimeout": NotRequired[bool],
+        "database": NotRequired[str],
+        "includeResultMetadata": NotRequired[bool],
+        "parameters": NotRequired[Sequence["SqlParameterTypeDef"]],
+        "resultSetOptions": NotRequired["ResultSetOptionsTypeDef"],
+        "schema": NotRequired[str],
+        "transactionId": NotRequired[str],
     },
 )
-_OptionalExecuteStatementRequestRequestTypeDef = TypedDict(
-    "_OptionalExecuteStatementRequestRequestTypeDef",
-    {
-        "continueAfterTimeout": bool,
-        "database": str,
-        "includeResultMetadata": bool,
-        "parameters": Sequence["SqlParameterTypeDef"],
-        "resultSetOptions": "ResultSetOptionsTypeDef",
-        "schema": str,
-        "transactionId": str,
-    },
-    total=False,
-)
-
-
-class ExecuteStatementRequestRequestTypeDef(
-    _RequiredExecuteStatementRequestRequestTypeDef, _OptionalExecuteStatementRequestRequestTypeDef
-):
-    pass
-
 
 ExecuteStatementResponseTypeDef = TypedDict(
     "ExecuteStatementResponseTypeDef",
@@ -243,23 +189,21 @@ ExecuteStatementResponseTypeDef = TypedDict(
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
-        "arrayValue": "ArrayValueTypeDef",
-        "blobValue": Union[bytes, IO[bytes], StreamingBody],
-        "booleanValue": bool,
-        "doubleValue": float,
-        "isNull": bool,
-        "longValue": int,
-        "stringValue": str,
+        "arrayValue": NotRequired["ArrayValueTypeDef"],
+        "blobValue": NotRequired[Union[bytes, IO[bytes], StreamingBody]],
+        "booleanValue": NotRequired[bool],
+        "doubleValue": NotRequired[float],
+        "isNull": NotRequired[bool],
+        "longValue": NotRequired[int],
+        "stringValue": NotRequired[str],
     },
-    total=False,
 )
 
 RecordTypeDef = TypedDict(
     "RecordTypeDef",
     {
-        "values": List["ValueTypeDef"],
+        "values": NotRequired[List["ValueTypeDef"]],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -276,27 +220,24 @@ ResponseMetadataTypeDef = TypedDict(
 ResultFrameTypeDef = TypedDict(
     "ResultFrameTypeDef",
     {
-        "records": List["RecordTypeDef"],
-        "resultSetMetadata": "ResultSetMetadataTypeDef",
+        "records": NotRequired[List["RecordTypeDef"]],
+        "resultSetMetadata": NotRequired["ResultSetMetadataTypeDef"],
     },
-    total=False,
 )
 
 ResultSetMetadataTypeDef = TypedDict(
     "ResultSetMetadataTypeDef",
     {
-        "columnCount": int,
-        "columnMetadata": List["ColumnMetadataTypeDef"],
+        "columnCount": NotRequired[int],
+        "columnMetadata": NotRequired[List["ColumnMetadataTypeDef"]],
     },
-    total=False,
 )
 
 ResultSetOptionsTypeDef = TypedDict(
     "ResultSetOptionsTypeDef",
     {
-        "decimalReturnType": DecimalReturnTypeType,
+        "decimalReturnType": NotRequired[DecimalReturnTypeType],
     },
-    total=False,
 )
 
 RollbackTransactionRequestRequestTypeDef = TypedDict(
@@ -319,51 +260,46 @@ RollbackTransactionResponseTypeDef = TypedDict(
 SqlParameterTypeDef = TypedDict(
     "SqlParameterTypeDef",
     {
-        "name": str,
-        "typeHint": TypeHintType,
-        "value": "FieldTypeDef",
+        "name": NotRequired[str],
+        "typeHint": NotRequired[TypeHintType],
+        "value": NotRequired["FieldTypeDef"],
     },
-    total=False,
 )
 
 SqlStatementResultTypeDef = TypedDict(
     "SqlStatementResultTypeDef",
     {
-        "numberOfRecordsUpdated": int,
-        "resultFrame": "ResultFrameTypeDef",
+        "numberOfRecordsUpdated": NotRequired[int],
+        "resultFrame": NotRequired["ResultFrameTypeDef"],
     },
-    total=False,
 )
 
 StructValueTypeDef = TypedDict(
     "StructValueTypeDef",
     {
-        "attributes": List[Dict[str, Any]],
+        "attributes": NotRequired[List[Dict[str, Any]]],
     },
-    total=False,
 )
 
 UpdateResultTypeDef = TypedDict(
     "UpdateResultTypeDef",
     {
-        "generatedFields": List["FieldTypeDef"],
+        "generatedFields": NotRequired[List["FieldTypeDef"]],
     },
-    total=False,
 )
 
 ValueTypeDef = TypedDict(
     "ValueTypeDef",
     {
-        "arrayValues": List[Dict[str, Any]],
-        "bigIntValue": int,
-        "bitValue": bool,
-        "blobValue": bytes,
-        "doubleValue": float,
-        "intValue": int,
-        "isNull": bool,
-        "realValue": float,
-        "stringValue": str,
-        "structValue": Dict[str, Any],
+        "arrayValues": NotRequired[List[Dict[str, Any]]],
+        "bigIntValue": NotRequired[int],
+        "bitValue": NotRequired[bool],
+        "blobValue": NotRequired[bytes],
+        "doubleValue": NotRequired[float],
+        "intValue": NotRequired[int],
+        "isNull": NotRequired[bool],
+        "realValue": NotRequired[float],
+        "stringValue": NotRequired[str],
+        "structValue": NotRequired[Dict[str, Any]],
     },
-    total=False,
 )
